import React, { useMemo } from "react";
import { Button, Card, Form, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { useSearchParams, useNavigate } from "react-router-dom";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import {
  getFxUserId,
  postFxUser,
  putFxUser,
  postFxUserAndLogin,
  putFxUserAndLogin,
} from "@/services/fxuser";
const { Option } = Select;

export default (props) => {
  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();

  const [searchParams] = useSearchParams();
  const [form] = Form.useForm();
  const navigate = useNavigate();

  const id = searchParams.get("id");

  React.useEffect(() => {
    if (id) {
      getFxUserId(id).then((res) => {
        form.setFieldsValue(res);
      });
    }
  });

  const onFinish = (values) => {
    console.log(values);
    startSubmit();
    if (id) {
      //修改
      putFxUserAndLogin(id, values)
        .then((res) => {
          cancelSubmit();
          navigate(-1);
        })
        .catch(() => {
          cancelSubmit();
        });
    } else {
      //新增
      postFxUserAndLogin(values)
        .then((res) => {
          cancelSubmit();
          navigate(-1);
        })
        .catch(() => {
          cancelSubmit();
        });
    }
  };

  return (
    <Page>
      <Card loading={loading}>
        <Form
          onFinish={onFinish}
          form={form}
          {...formItemLayout}
          scrollToFirstError
          style={{ maxWidth: "1000px" }}
        >
          <Form.Item
            name="userName"
            label="用户名称"
            rules={[
              {
                required: true,
                message: "请填写用户名称",
              },
            ]}
          >
            <Input placeholder="请输入用户名称" />
          </Form.Item>
          <Form.Item
            name="phone"
            label="手机号"
            rules={[
              {
                required: true,
                message: "请填写手机号",
              },
            ]}
          >
            <Input placeholder="请输入手机号" />
          </Form.Item>
          {id ? null : (
            <Form.Item label="账 户">
              <div style={{ color: "#333" }}>手机号；默认密码：123456</div>
            </Form.Item>
          )}
          <Form.Item {...tailFormItemLayout}>
            <Button loading={submiting} type="primary" htmlType="submit">
              保存
            </Button>
            <Button style={{ marginLeft: "2em" }} onClick={() => navigate(-1)}>
              返回
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </Page>
  );
};
